@@ -18,6 +18,7 @@
 package coremain
 
 import (
+	"bytes"
 	"github.com/IrineSistiana/mosdns/v3/dispatcher/handler"
 	"gopkg.in/yaml.v3"
 	"os"
@@ -49,7 +50,9 @@ func parseConfig(f string) (*Config, error) {
 	}
 
 	c := new(Config)
-	if err := yaml.Unmarshal(b, c); err != nil {
+	yamlDecoder := yaml.NewDecoder(bytes.NewReader(b))
+	yamlDecoder.KnownFields(true)
+	if err := yamlDecoder.Decode(c); err != nil {
 		return nil, err
 	}
 
