@@ -18,21 +18,25 @@
 package cache
 
 import (
-	"context"
 	"io"
 	"time"
 )
 
 // Backend represents a cache backend.
+// The Backend does not raise errors cause a cache error is not a
+// fatal error to a dns query. The caller usually does not care too
+// much about the cache error. Implements should handle errors themselves.
+// Cache Backend is expected to be very fast. All operations should be
+// done (or returned) in a short time. e.g. 50 ms.
 type Backend interface {
 	// Get retrieves v from Backend. The returned v may be the original value. The caller should
 	// not modify it.
-	Get(ctx context.Context, key string) (v []byte, storedTime, expirationTime time.Time, err error)
+	Get(key string) (v []byte, storedTime, expirationTime time.Time)
 
 	// Store stores a copy of v into Backend. v cannot be nil.
 	// If expirationTime is already passed, Store is a noop.
-	Store(ctx context.Context, key string, v []byte, storedTime, expirationTime time.Time) error
+	Store(key string, v []byte, storedTime, expirationTime time.Time)
 
-	// Closer closes the cache backend.
+	// Closer closes the cache backend. Get and Store should become noop calls.
 	io.Closer
 }
