@@ -19,15 +19,20 @@ package dnsutils
 
 import (
 	"encoding/binary"
+	"errors"
 	"fmt"
 	"github.com/IrineSistiana/mosdns/v3/dispatcher/pkg/pool"
 	"github.com/miekg/dns"
 	"io"
 )
 
-// ReadRawMsgFromTCP reads msg from c in RFC 7766 format.
+var (
+	errZeroLenMsg = errors.New("zero length msg")
+)
+
+// ReadRawMsgFromTCP reads msg from c in RFC 1035 format (msg is prefixed
+// with a two byte length field).
 // n represents how many bytes are read from c.
-// This includes two-octet length field.
 func ReadRawMsgFromTCP(c io.Reader) (*pool.Buffer, int, error) {
 	n := 0
 	hb := pool.GetBuf(2)
@@ -41,6 +46,10 @@ func ReadRawMsgFromTCP(c io.Reader) (*pool.Buffer, int, error) {
 
 	// dns length
 	length := binary.BigEndian.Uint16(h)
+	if length == 0 {
+		return nil, 0, errZeroLenMsg
+	}
+
 	buf := pool.GetBuf(int(length))
 
 	nm, err := io.ReadFull(c, buf.Bytes())
@@ -53,18 +62,28 @@ func ReadRawMsgFromTCP(c io.Reader) (*pool.Buffer, int, error) {
 	return buf, n, nil
 }
 
-// WriteMsgToTCP packs and writes m to c in RFC 7766 format.
+// ReadMsgFromTCP reads msg from c in RFC 1035 format (msg is prefixed
+// with a two byte length field).
+// n represents how many bytes are read from c.
+func ReadMsgFromTCP(c io.Reader) (*dns.Msg, int, error) {
+	b, n, err := ReadRawMsgFromTCP(c)
+	if err != nil {
+		return nil, 0, err
+	}
+	defer b.Release()
+
+	m, err := unpackMsgWithDetailedErr(b.Bytes())
+	return m, n, err
+}
+
+// WriteMsgToTCP packs and writes m to c in RFC 1035 format.
 // n represents how many bytes are written to c.
-// This includes 2 bytes length header.
-// An io err will be wrapped into an IOErr.
-// IsIOErr(err) can check and unwrap the inner io err.
 func WriteMsgToTCP(c io.Writer, m *dns.Msg) (n int, err error) {
 	mRaw, buf, err := pool.PackBuffer(m)
 	if err != nil {
 		return 0, err
 	}
 	defer buf.Release()
-
 	return WriteRawMsgToTCP(c, mRaw)
 }
 
@@ -82,3 +101,38 @@ func WriteRawMsgToTCP(c io.Writer, b []byte) (n int, err error) {
 	copy(wb[2:], b)
 	return c.Write(wb)
 }
+
+func WriteMsgToUDP(c io.Writer, m *dns.Msg) (int, error) {
+	b, buf, err := pool.PackBuffer(m)
+	if err != nil {
+		return 0, err
+	}
+	defer buf.Release()
+
+	return c.Write(b)
+}
+
+func ReadMsgFromUDP(c io.Reader, bufSize int) (*dns.Msg, int, error) {
+	if bufSize < dns.MinMsgSize {
+		bufSize = dns.MinMsgSize
+	}
+
+	buf := pool.GetBuf(bufSize)
+	defer buf.Release()
+	b := buf.Bytes()
+	n, err := c.Read(b)
+	if err != nil {
+		return nil, n, err
+	}
+
+	m, err := unpackMsgWithDetailedErr(b[:n])
+	return m, n, err
+}
+
+func unpackMsgWithDetailedErr(b []byte) (*dns.Msg, error) {
+	m := new(dns.Msg)
+	if err := m.Unpack(b); err != nil {
+		return nil, fmt.Errorf("failed to unpack msg [%x], %w", b, err)
+	}
+	return m, nil
+}
