@@ -5,7 +5,6 @@ import (
 	"errors"
 	"fmt"
 	"github.com/IrineSistiana/mosdns/v3/dispatcher/pkg/dnsutils"
-	"github.com/IrineSistiana/mosdns/v3/dispatcher/pkg/pool"
 	"github.com/miekg/dns"
 	"go.uber.org/zap"
 	"io"
@@ -43,33 +42,33 @@ func TestTransport_Exchange(t *testing.T) {
 		return nil, errors.New("dial err")
 	}
 
-	write := func(c io.Writer, m []byte) (n int, err error) {
+	write := func(c io.Writer, m *dns.Msg) (n int, err error) {
 		randSleep20()
-		return dnsutils.WriteRawMsgToTCP(c, m)
+		return dnsutils.WriteMsgToTCP(c, m)
 	}
 
-	read := func(c io.Reader) (m *pool.Buffer, n int, err error) {
+	read := func(c io.Reader) (m *dns.Msg, n int, err error) {
 		randSleep20()
-		return dnsutils.ReadRawMsgFromTCP(c)
+		return dnsutils.ReadMsgFromTCP(c)
 	}
 
-	writeErr := func(c io.Writer, m []byte) (n int, err error) {
+	writeErr := func(c io.Writer, m *dns.Msg) (n int, err error) {
 		return 0, errors.New("write err")
 	}
 
-	readErr := func(c io.Reader) (m *pool.Buffer, n int, err error) {
+	readErr := func(c io.Reader) (m *dns.Msg, n int, err error) {
 		return nil, 0, errors.New("read err")
 	}
 
-	readTimeout := func(c io.Reader) (m *pool.Buffer, n int, err error) {
+	readTimeout := func(c io.Reader) (m *dns.Msg, n int, err error) {
 		time.Sleep(time.Second * 1)
 		return nil, 0, errors.New("read err")
 	}
 
 	type fields struct {
 		DialFunc       func(ctx context.Context) (net.Conn, error)
-		WriteFunc      func(c io.Writer, m []byte) (n int, err error)
-		ReadFunc       func(c io.Reader) (m *pool.Buffer, n int, err error)
+		WriteFunc      func(c io.Writer, m *dns.Msg) (n int, err error)
+		ReadFunc       func(c io.Reader) (m *dns.Msg, n int, err error)
 		MaxConns       int
 		IdleTimeout    time.Duration
 		EnablePipeline bool
@@ -277,11 +276,7 @@ func TestTransport_Exchange(t *testing.T) {
 			if tt.wantErr {
 				q := new(dns.Msg)
 				q.SetQuestion(".", dns.TypeA)
-				raw, err := q.Pack()
-				if err != nil {
-					t.Fatal(err)
-				}
-				_, err = transport.ExchangeContext(ctx, raw)
+				_, err := transport.ExchangeContext(ctx, q)
 				if err == nil {
 					t.Fatal("want err, but got nil err")
 				}
@@ -297,26 +292,15 @@ func TestTransport_Exchange(t *testing.T) {
 					q := new(dns.Msg)
 					qName := fmt.Sprintf("%d.", i)
 					q.SetQuestion(qName, dns.TypeA)
-					raw, err := q.Pack()
-					if err != nil {
-						t.Error(err)
-						return
-					}
 					ctx, cancel := context.WithTimeout(context.Background(), time.Millisecond*500)
 					defer cancel()
 
-					gotR, err := transport.ExchangeContext(ctx, raw)
+					r, err := transport.ExchangeContext(ctx, q)
 					if (err != nil) != tt.wantErr {
 						t.Errorf("Exchange() error = %v, wantErr %v", err, tt.wantErr)
 						return
 					}
 
-					r := new(dns.Msg)
-					if err := r.Unpack(gotR.Bytes()); err != nil {
-						t.Error(err)
-						return
-					}
-
 					if gotName := r.Question[0].Name; gotName != qName {
 						t.Errorf("Exchange() gotName = %v, want %v", gotName, qName)
 					}
