@@ -20,12 +20,12 @@ package responsematcher
 import (
 	"context"
 	"fmt"
-	"github.com/IrineSistiana/mosdns/v2/dispatcher/handler"
-	"github.com/IrineSistiana/mosdns/v2/dispatcher/pkg/matcher/domain"
-	"github.com/IrineSistiana/mosdns/v2/dispatcher/pkg/matcher/elem"
-	"github.com/IrineSistiana/mosdns/v2/dispatcher/pkg/matcher/msg_matcher"
-	"github.com/IrineSistiana/mosdns/v2/dispatcher/pkg/matcher/netlist"
-	"github.com/IrineSistiana/mosdns/v2/dispatcher/pkg/utils"
+	"github.com/IrineSistiana/mosdns/v3/dispatcher/handler"
+	"github.com/IrineSistiana/mosdns/v3/dispatcher/pkg/matcher/domain"
+	"github.com/IrineSistiana/mosdns/v3/dispatcher/pkg/matcher/elem"
+	"github.com/IrineSistiana/mosdns/v3/dispatcher/pkg/matcher/msg_matcher"
+	"github.com/IrineSistiana/mosdns/v3/dispatcher/pkg/matcher/netlist"
+	"github.com/IrineSistiana/mosdns/v3/dispatcher/pkg/utils"
 	"github.com/miekg/dns"
 	"go.uber.org/zap"
 )
@@ -35,7 +35,7 @@ const PluginType = "response_matcher"
 func init() {
 	handler.RegInitFunc(PluginType, Init, func() interface{} { return new(Args) })
 
-	handler.MustRegPlugin(preset(handler.NewBP("_response_rcode_success", PluginType), &Args{Rcode: []int{dns.RcodeSuccess}}), true)
+	handler.MustRegPlugin(preset(handler.NewBP("_response_rcode_success", PluginType), &Args{Rcode: []int{dns.RcodeSuccess}}))
 }
 
 var _ handler.MatcherPlugin = (*responseMatcher)(nil)
